@@ -1,5 +1,5 @@
 export { Bar } from './bar';
 export { Gauge } from './gauge';
 export { Line } from './line';
-export { Scalar } from './scalar';
+export { QueryBrowser } from './query-browser';
 export { Donut } from './donut';
