@@ -1,9 +1,11 @@
 import { NetworkPolicySidebar } from './network-policy-sidebar';
 import { RoleSidebar } from './role-sidebar';
 import { BuildConfigSidebar } from './build-config-sidebar';
+import { ResourceQuotaSidebar } from './resource-quota-sidebar';
 
 export const resourceSidebars = new Map<string, React.ComponentType<any>>()
-  .set('NetworkPolicy', NetworkPolicySidebar)
-  .set('Role', RoleSidebar)
+  .set('BuildConfig', BuildConfigSidebar)
   .set('ClusterRole', RoleSidebar)
-  .set('BuildConfig', BuildConfigSidebar);
+  .set('NetworkPolicy', NetworkPolicySidebar)
+  .set('ResourceQuota', ResourceQuotaSidebar)
+  .set('Role', RoleSidebar);
